
class Database:
    def __init__(self, **kwds):
        pass

    def Initialize(self):
        return

    def Sync(self):
        return

    def Find(self, table, params=None, sort=None):
        return []

    def FindOne(self, table, _id):
        return {}

    def Count(self, table):
        return 0

    def Insert(self, table, values):
        return

    def Update(self, table, values):
        return

    def Remove(self, table, _id):
        return
