// Generated by CoffeeScript 1.7.1
(function() {
  $(document).ready(function() {
    return console.log('Ready');
  });

  if (window.cancelEvent == null) {
    window.cancelEvent = function(event) {
      event.preventDefault();
      event.stopPropagation();
      return false;
    };
  }

}).call(this);

//# sourceMappingURL=example.map
